==> openorienteering-mapper_0.6.7.orig.tar.gz: mapper-0.6.7/doc/manual/pages/view_menu.md <==
---
title: View Menu
authors:
  - Peter Hoban
  - Thomas Schoeps
keywords: Menus
edited: 22 April 2013
---

<table><tr><td width="40"><img class="small" src="../mapper-images/move.png" width="32" height="32" border="0" alt="" /></td><td width="180"><h4>Pan</h4></td><td width="60"><h4>(F6)</h4></td><td width="400">
<p>Activates the <a href="toolbars.md#pan_map">pan tool</a> which can be used to move the map.
Note that key F6 starts panning immediately.</td></tr>

<tr><td><img class="small" src="../mapper-images/view-zoom-in.png" width="32" height="32" border="0" alt="" /></td><td><h4>Zoom in</h4></td><td><h4>F7</h4></td><td width="400">
<p>Zoom in (enlarge) to view the map closer. </td></tr>

<tr><td><img class="small" src="../mapper-images/view-zoom-out.png" width="32" height="32" border="0" alt="" /></td><td><h4>Zoom out</h4></td><td><h4>F8</h4></td><td>
<p>Zoom out (shrink) the map to see more of it.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/view-show-all.png" width="32" height="32" border="0" alt="" /></td><td><h4><a name="zoom-all">Show whole map</a></h4></td><td><h4></h4></td><td>
<p>Use this tool to display the whole map on your screen.  </p></td></tr>

<tr><td></td><td><h4>Set custom zoom factor...</h4></td><td><h4></h4></td><td>
<p>Shows a dialog to enter a specific zoom factor. Note that the zoom factor on the screen is not necessarily equal to the printed scale of the map.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/grid.png" width="32" height="32" border="0" alt="" /></td><td><h4>Show grid</h4></td><td><h4>G</h4></td><td>
<p>Shows or hides the <a href="grid.md">map grid</a>.</p></td></tr>

<tr><td></td><td><h4>Hatch areas</h4></td><td><h4>F2</h4></td><td>
<p>When this toggle is activated, all area objects in the map will be drawn in a hatched, semi-transparent style. This is useful to be able to see any templates below the map.</p></td></tr>

<tr><td></td><td><h4>Baseline view</h4></td><td><h4>F3</h4></td><td>
<p>When this toggle is activated, instead of the normal appearance of map objects only their midpoints respectively baselines are displayed. This can be combined with Hatch areas to see anything below the map even better.</p></td></tr>

<tr><td></td><td><h4><a name="overprinting">Overprinting simulation</a></h4></td><td><h4>F4</h4></td><td>
<p>When this toggle is activated, the effect of printing the map with layers of spot colors on top of each other will be simulated. This leads to improved map readability. This function requires a color set with spot color definitions.</p></td></tr>

<tr><td></td><td><h4>Hide all templates</h4></td><td><h4>F10</h4></td><td>
<p>When this toggle is activated, no templates will be displayed. This is useful to check the appearance of the map alone.</p></td></tr>

<tr><td colspan="4"><a name="coorddisplay"><h4>Display coordinates as ...</h4></a>
<p>The coordinates of the cursor on the map are shown in the position box at the bottom right corner of the program window. Paper coordinates refer to positions on a paper print, from an arbitrary origin. If your map has been <a href="georeferencing.md">georeferenced</a>, additional coordinate systems will be available. Projected coordinates are meters of easting and northing. Latitude &amp; longitude may be expressed in decimal degrees or in degrees, minutes and seconds.</p>
<p>The coordinate system may also be selected by a right-click on the position box at the bottom right corner of your screen which will provide the same choices.<br/><br/></p></td></tr>

<tr><td></td><td><a name="fullscreen"><h4>Toggle fullscreen mode</h4></a></td><td><h4>F11</h4></td><td>
<p>This toggle switches the display to full-screen mode and back.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/window-new.png" width="32" height="32" border="0" alt="" /></td><td><h4>Tag editor</h4></td><td><h4>Ctrl+Shift+6</h4></td><td>
<p>This toggle shows or hides the <a href="tag_editor.md">tag editor</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/colors.png" width="32" height="32" border="0" alt="" /></td><td><h4>Color window</h4></td><td><h4>Ctrl+Shift+7</h4></td><td>
<p>This toggle shows or hides the <a href="color_dock_widget.md">color window</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/symbols.png" width="32" height="32" border="0" alt="" /></td><td><h4>Symbol window</h4></td><td><h4>Ctrl+Shift+8</h4></td><td>
<p>This toggle shows or hides the <a href="symbol_dock_widget.md">symbol pane</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/templates.png" width="32" height="32" border="0" alt="" /></td><td><h4>Template setup window</h4></td><td><h4>Ctrl+Shift+9</h4></td><td>
<p>This toggle shows or hides the <a href="templates.md#setup">template setup window</a>.</p></td></tr>

</table>

==> openorienteering-mapper_0.7.0.orig.tar.gz: mapper-0.7.0/doc/manual/pages/view_menu.md <==
---
title: View Menu
authors:
  - Peter Hoban
  - Thomas Schoeps
keywords: Menus
edited: 22 April 2013
---

<table><tr><td width="40"><img class="small" src="../mapper-images/move.png" width="32" height="32" border="0" alt="" /></td><td width="180"><h4>Pan</h4></td><td width="60"><h4>(F6)</h4></td><td width="400">
<p>Activates the <a href="toolbars.md#pan_map">pan tool</a> which can be used to move the map.
Note that key F6 starts panning immediately.</td></tr>

<tr><td><img class="small" src="../mapper-images/view-zoom-in.png" width="32" height="32" border="0" alt="" /></td><td><h4>Zoom in</h4></td><td><h4>F7</h4></td><td width="400">
<p>Zoom in (enlarge) to view the map closer. </td></tr>

<tr><td><img class="small" src="../mapper-images/view-zoom-out.png" width="32" height="32" border="0" alt="" /></td><td><h4>Zoom out</h4></td><td><h4>F8</h4></td><td>
<p>Zoom out (shrink) the map to see more of it.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/view-show-all.png" width="32" height="32" border="0" alt="" /></td><td><h4><a name="zoom-all">Show whole map</a></h4></td><td><h4></h4></td><td>
<p>Use this tool to display the whole map on your screen.  </p></td></tr>

<tr><td></td><td><h4>Set custom zoom factor...</h4></td><td><h4></h4></td><td>
<p>Shows a dialog to enter a specific zoom factor. Note that the zoom factor on the screen is not necessarily equal to the printed scale of the map.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/grid.png" width="32" height="32" border="0" alt="" /></td><td><h4>Show grid</h4></td><td><h4>G</h4></td><td>
<p>Shows or hides the <a href="grid.md">map grid</a>.</p></td></tr>

<tr><td></td><td><h4>Hatch areas</h4></td><td><h4>F2</h4></td><td>
<p>When this toggle is activated, all area objects in the map will be drawn in a hatched, semi-transparent style. This is useful to be able to see any templates below the map.</p></td></tr>

<tr><td></td><td><h4>Baseline view</h4></td><td><h4>F3</h4></td><td>
<p>When this toggle is activated, instead of the normal appearance of map objects only their midpoints respectively baselines are displayed. This can be combined with Hatch areas to see anything below the map even better.</p></td></tr>

<tr><td></td><td><h4><a name="overprinting">Overprinting simulation</a></h4></td><td><h4>F4</h4></td><td>
<p>When this toggle is activated, the effect of printing the map with layers of spot colors on top of each other will be simulated. This leads to improved map readability. This function requires a color set with spot color definitions.</p></td></tr>

<tr><td></td><td><h4>Hide all templates</h4></td><td><h4>F10</h4></td><td>
<p>When this toggle is activated, no templates will be displayed. This is useful to check the appearance of the map alone.</p></td></tr>

<tr><td colspan="4"><a name="coorddisplay"><h4>Display coordinates as ...</h4></a>
<p>The coordinates of the cursor on the map are shown in the position box at the bottom right corner of the program window. Paper coordinates refer to positions on a paper print, from an arbitrary origin. If your map has been <a href="georeferencing.md">georeferenced</a>, additional coordinate systems will be available. Projected coordinates are meters of easting and northing. Latitude &amp; longitude may be expressed in decimal degrees or in degrees, minutes and seconds.</p>
<p>The coordinate system may also be selected by a right-click on the position box at the bottom right corner of your screen which will provide the same choices.<br/><br/></p></td></tr>

<tr><td></td><td><a name="fullscreen"><h4>Toggle fullscreen mode</h4></a></td><td><h4>F11</h4></td><td>
<p>This toggle switches the display to full-screen mode and back.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/tag-selector.png" width="32" height="32" border="0" alt="" /></td><td><h4>Tag selector</h4></td><td><h4>Ctrl+Shift+5</h4></td><td>
<p>This toggle shows or hides the <a href="tag_selector.md">tag selector</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/window-new.png" width="32" height="32" border="0" alt="" /></td><td><h4>Tag editor</h4></td><td><h4>Ctrl+Shift+6</h4></td><td>
<p>This toggle shows or hides the <a href="tag_editor.md">tag editor</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/colors.png" width="32" height="32" border="0" alt="" /></td><td><h4>Color window</h4></td><td><h4>Ctrl+Shift+7</h4></td><td>
<p>This toggle shows or hides the <a href="color_dock_widget.md">color window</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/symbols.png" width="32" height="32" border="0" alt="" /></td><td><h4>Symbol window</h4></td><td><h4>Ctrl+Shift+8</h4></td><td>
<p>This toggle shows or hides the <a href="symbol_dock_widget.md">symbol pane</a>.</p></td></tr>

<tr><td><img class="small" src="../mapper-images/templates.png" width="32" height="32" border="0" alt="" /></td><td><h4>Template setup window</h4></td><td><h4>Ctrl+Shift+9</h4></td><td>
<p>This toggle shows or hides the <a href="templates.md#setup">template setup window</a>.</p></td></tr>

</table>
